(function ($) {
$.Redactor.opts.langs['sk'] = {
	html: 'HTML',
	video: 'Video',
	image: 'Obrázok',
	table: 'Tabulka',
	link: 'Odkaz',
	link_insert: 'Vložiť odkaz ...',
	link_edit: 'Edit link',
	unlink: 'Odstrániť odkaz',
	formatting: 'Štýl',
	paragraph: 'Odstavec',
	quote: 'Citácia',
	code: 'Kód',
	header1: 'Nadpis 1',
	header2: 'Nadpis 2',
	header3: 'Nadpis 3',
	header4: 'Nadpis 4',
	header5: 'Nadpis 5',
	bold:  'Tučné',
	italic: 'Kurzíva',
	fontcolor: 'Farba písma',
	backcolor: 'Farba pozadia',
	unorderedlist: 'Zoznam s odrážkami',
	orderedlist: 'Číslovaný zoznam',
	outdent: 'Zmenšiť odsadenie',
	indent: 'Zväčšiť odsadenie',
	cancel: 'Zrušiť',
	insert: 'Vložiť',
	save: 'Uložiť',
	_delete: 'Smazať',
	insert_table: 'Vložiť tabulku',
	insert_row_above: 'Pridať riadok hore',
	insert_row_below: 'Pridať riadok dole',
	insert_column_left: 'Pridať stĺpec vľavo',
	insert_column_right: 'Pridať stľpec vpravo',
	delete_column: 'Zmazať stľpec',
	delete_row: 'Zmazať riadok',
	delete_table: 'Zmazať tabulku',
	rows: 'Riadky',
	columns: 'Stľpce',
	add_head: 'Pridať záhlavie',
	delete_head: 'Zmazať záhlavie',
	title: 'Titulok',
	image_position: 'Pozícia',
	none: 'žiadny',
	left: 'vľavo',
	right: 'vpravo',
	image_web_link: 'Odkaz na obrázok',
	text: 'Text',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Kód pre vloženie videa na stránku',
	file: 'Súbor',
	upload: 'Nahrát',
	download: 'Stiahnúť',
	choose: 'Vybrať',
	or_choose: 'alebo',
	drop_file_here: 'Pretiahnite súbor sem',
	align_left:	'Zarovnať vľavo',
	align_center: 'Zarovnať na stred',
	align_right: 'Zarovnať vpravo',
	align_justify: 'Zarovnať do bloku',
	horizontalrule: 'Vodorovná  čiara',
	fullscreen: 'Celá obrazovka',
	deleted: 'Prečiarknuté',
	anchor: 'Záložka',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
