(function ($) {
$.Redactor.opts.langs['zh_tw'] = {
	html: 'HTML',
	video: '插入影片',
	image: '插入圖片',
	table: '表格',
	link: '連結',
	link_insert: '插入連結',
	link_edit: 'Edit link',
	unlink: '移除連結',
	formatting: '樣式',
	paragraph: '段落',
	quote: '引用',
	code: '原始碼',
	header1: '標題 1',
	header2: '標題 2',
	header3: '標題 3',
	header4: '標題 4',
	header5: '標題 5',
	bold:  '將文字變成粗體',
	italic: '將文字變成斜體',
	fontcolor: '選擇文字顏色',
	backcolor: '選擇文字底色',
	unorderedlist: '項目列表',
	orderedlist: '編號列表',
	outdent: '減少縮排',
	indent: '增加縮排',
	cancel: '取消',
	insert: '插入',
	save: '儲存',
	_delete: '刪除',
	insert_table: '插入表格',
	insert_row_above: '加入上方橫列',
	insert_row_below: '加入下方橫列',
	insert_column_left: '加入左方直欄',
	insert_column_right: '加入右方直欄',
	delete_column: '刪除整欄',
	delete_row: '刪除整列',
	delete_table: '刪除表格',
	rows: '橫列',
	columns: '直欄',
	add_head: '加入表格標題',
	delete_head: '刪除表格標題',
	title: '標題',
	image_position: '位置',
	none: '無',
	left: '靠左',
	right: '靠右',
	image_web_link: '連結',
	text: '內文',
	mailto: 'Email',
	web: '網址',
	video_html_code: '嵌入影片的原始碼',
	file: '插入文件',
	upload: '上傳',
	download: '下載',
	choose: '選擇',
	or_choose: '或選擇',
	drop_file_here: '將文件拖曳至此',
	align_left:	'將文字對齊至左側',
	align_center: '將文字置中',
	align_right: '將文字對齊至右側',
	align_justify: '對齊至兩側',
	horizontalrule: '插入水平線',
	fullscreen: '全銀幕',
	deleted: '刪除線',
	anchor: '錨點',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );