(function($) {
	$.Redactor.opts.langs['hr'] = {
		html: 'HTML',
		video: 'Umetni video',
		image: 'Umetni sliku',
		table: 'Tablica',
		link: 'Poveznica',
		link_insert: 'Umetni poveznicu',
		link_edit: 'Uredi poveznicu',
		unlink: 'Ukloni poveznicu',
		formatting: 'Ure&#273ivanje',
		paragraph: 'Paragraf',
		quote: 'Umetni citat',
		code: 'Izvorni k&ocirc;d',
		header1: 'Zaglavlje 1',
		header2: 'Zaglavlje 2',
		header3: 'Zaglavlje 3',
		header4: 'Zaglavlje 4',
		header5: 'Zaglavlje 5',
		bold: 'Podebljaj',
		italic: 'Nakosi',
		fontcolor: 'Boja slova',
		backcolor: 'Boja pozadine',
		unorderedlist: 'Nesortirana lista',
		orderedlist: 'Sortirana lista',
		outdent: 'Izvuci',
		indent: 'Uvuci',
		cancel: 'Odustani',
		insert: 'Umetni',
		save: 'Spremi',
		_delete: 'Izbri&scaron;i',
		insert_table: 'Umetni tablicu',
		insert_row_above: 'Dodaj redak iznad',
		insert_row_below: 'Dodaj redak ispod',
		insert_column_left: 'Dodaj stupac lijevo',
		insert_column_right: 'Dodaj stupac desno',
		delete_column: 'Ukloni stupac',
		delete_row: 'Ukloni redak',
		delete_table: 'Ukloni tablicu',
		rows: 'Redaka',
		columns: 'Stupaca',
		add_head: 'Dodaj zaglavlje',
		delete_head: 'Ukloni zaglavlje',
		title: 'Naslov',
		image_position: 'Poravnanje',
		none: 'Nema',
		left: 'lijevo',
		right: 'desno',
		center: 'centriraj',
		image_web_link: 'Internet adresa slike',
		text: 'Tekst',
		mailto: 'Email',
		web: 'Internet adresa',
		video_html_code: 'Video k&ocirc;d',
		file: 'Umetni datoteku',
		upload: 'Po&scaron;alji datoteku',
		download: 'Preuzmi datoteku',
		choose: 'Odaberi',
		or_choose: 'ili ru&#269no odaberi',
		drop_file_here: 'Povuci datoteku ovdje',
		align_left: 'Poravnaj lijevo',
		align_center: 'Centriraj',
		align_right: 'Poravnaj desno',
		align_justify: 'Od ruba do ruba',
		horizontalrule: 'Umetni horizontalnu crtu',
		deleted: 'Precrtaj',
		anchor: 'Sidro',
		link_new_tab: 'Otvori u novom prozoru',
		underline: 'Podvuci',
		alignment: 'Poravnanje',
		filename: 'Naziv (neobavezno)',
		edit: 'Uredi',
		fullscreen: 'Cijeli zaslon'
	};
})(jQuery);