(function ($) {
$.Redactor.opts.langs['da'] = {
    html: 'HTML',
    video: 'Indsæt Video...',
    image: 'Indsæt Billede...',
    table: 'Tabel',
    link: 'Hyperlink',
    link_insert: 'Indsæt Hyperlink ...',
    link_edit: 'Edit link',
    unlink: 'Fjern Hyperlink',
    formatting: 'Formatering',
    paragraph: 'Paragraf',
    quote: 'Citat',
    code: 'Kode',
    header1: 'Overskrift 1',
    header2: 'Overskrift 2',
    header3: 'Overskrift 3',
    header4: 'Overskrift 4',
    header5: 'Overskrift 5',
    bold:  'Fed',
    italic: 'Kursiv',
    fontcolor: 'Skriftfarve',
    backcolor: 'Baggrundsfarve',
    unorderedlist: 'Opstilling Med Punkttegn',
    orderedlist: 'Opstilling Med Tal',
    outdent: 'Formindsk Indrykning',
    indent: 'Forøg Indrykning',
    cancel: 'Fortryd',
    insert: 'Indsæt',
    save: 'Gem',
    _delete: 'Slet',
    insert_table: 'Indsæt Tabel...',
    insert_row_above: 'Indsæt Række Over',
    insert_row_below: 'Indsæt Række Under',
    insert_column_left: 'Indsæt Kolonne Venstre',
    insert_column_right: 'Indsæt Kolonne Højre',
    delete_column: 'Slet Kolonne',
    delete_row: 'Slet Række',
    delete_table: 'Slet Tabel',
    rows: 'Rækker',
    columns: 'Kolonner',
    add_head: 'Indsæt Hoved',
    delete_head: 'Slet Hoved',
    title: 'Titel',
    image_position: 'Placering',
    none: 'Ingen',
    left: 'Venstre',
    right: 'Højre',
    image_web_link: 'Billede Web Hyperlink',
    text: 'Tekst',
    mailto: 'Email',
    web: 'URL',
    video_html_code: 'Video Indlejringskode',
    file: 'Indsæt Fil...',
    upload: 'Upload',
    download: 'Download',
    choose: 'Vælg',
    or_choose: 'Eller vælg',
    drop_file_here: 'Træk fil her',
    align_left: 'Venstrejuster',
    align_center: 'Centrer',
    align_right: 'Højrejuster',
    align_justify: 'Juster',
    horizontalrule: 'Indsæt Vandret Linje',
    fullscreen: 'Fuldskærm',
    deleted: 'Slettet',
    anchor: 'Anchor',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );