(function ($) {
$.Redactor.opts.langs['sl'] = {
	html: 'HTML',
	video: 'Video',
	image: 'Slika',
	table: 'Tabela',
	link: 'Povezava',
	link_insert: 'Vstavi povezavo...',
	link_edit: 'Edit link',
	unlink: 'Odstrani povezavo',
	formatting: 'Stili',
	paragraph: 'Odstavek',
	quote: 'Citat',
	code: 'HTML koda',
	header1: 'Naslov 1',
	header2: 'Naslov 2',
	header3: 'Naslov 3',
	header4: 'Naslov 4',
	header5: 'Naslov 5',
	bold: 'Odebeljeno',
	italic: 'Poševno',
	fontcolor: 'Barva pisave',
	backcolor: 'Barva ozadja',
	unorderedlist: 'Nesortirana lista',
	orderedlist: 'Sortirana lista',
	outdent: 'Pomik levo',
	indent: 'Pomik desno',
	redo: 'Naprej',
	undo: 'Nazaj',
	cut: 'Izreži',
	cancel: 'Prekini',
	insert: 'Vstavi',
	save: 'Shrani',
	_delete: 'Izbriši',
	insert_table: 'Vstavi tabelo',
	insert_row_above: 'Dodaj vrstico nad',
	insert_row_below: 'Dodaj vrstico pod',
	insert_column_left: 'Dodaj stolpec levo',
	insert_column_right: 'Dodaj stolpec desno',
	delete_column: 'Izbriši stolpec',
	delete_row: 'Izbriši vrstivo',
	delete_table: 'Izbriši tabelo',
	rows: 'Vrstic',
	columns: 'Stolpcev',
	add_head: 'Dodaj naslov',
	delete_head: 'Odstrani naslov',
	title: 'Naslov',
	image_position: 'Poravnava',
	none: 'brez',
	left: 'levo',
	right: 'desno',
	image_web_link: 'Povezava do slike',
	text: 'Besedilo',
	mailto: 'Email',
	web: 'WEB povezava',
	video_html_code: 'Koda videa',
	file: 'Datoteka',
	upload: 'Pošalji',
	download: 'Prenesi',
	choose: 'Izberi',
	or_choose: 'ali izberi',
	drop_file_here: 'Povleci datoteko sem',
	align_left:	'Poravnaj levo',
	align_center: 'Centriraj',
	align_right: 'Poravnaj desno',
	align_justify: 'Od roba do roba',
	horizontalrule: 'Horizontalna crta',
	fullscreen: 'Čez cel ekran',
	deleted: 'Izbrisano',
	anchor: 'Sidro',
	link_new_tab: 'Odpri povezavo v novem oknu/tabu',
	underline: 'Podčrtano',
	alignment: 'Poravnava',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
