(function ($) {
$.Redactor.opts.langs['ge'] = {
	html: 'HTML კოდი',
	video: 'ვიდეოს ჩასმა',
	image: 'სურათის ჩასმა',
	table: 'ცხრილი',
	link: 'ბმული',
	link_insert: 'ბმულის ჩასმა',
	link_edit: 'ბმულის რედაქტირება',
	unlink: 'ბმულის გაუქმება',
	formatting: 'ტექსტის ფორმატირება',
	paragraph: 'პარაგრაფი',
	quote: 'ციტატა',
	code: 'კოდი',
	header1: 'სათაური 1',
	header2: 'სათაური 2',
	header3: 'სათაური 3',
	header4: 'სათაური 4',
	header5: 'სათაური 5',
	bold:  'მსხვილი',
	italic: 'დახრილი',
	fontcolor: 'ტექსტის ფერი',
	backcolor: 'ფონის ფერი',
	unorderedlist: 'დაუნომრავი სია',
	orderedlist: 'დანომრილი სია',
	outdent: 'ტექსტის გამოწევა',
	indent: 'ტექსტის შეწევა',
	cancel: 'გაუქმება',
	insert: 'ჩასმა',
	save: 'შენახვა',
	_delete: 'წაშლა',
	insert_table: 'ცხრილის ჩასმა',
	insert_row_above: 'რიგის ზემოდან დამატება',
	insert_row_below: 'რიგის ქვემოდან დამატება',
	insert_column_left: 'სვეტის მარცხნიდან დამატება',
	insert_column_right: 'სვეტის მარჯვნიდან დამატება',
	delete_column: 'სვეტის წაშლა',
	delete_row: 'რიგის წაშლა',
	delete_table: 'ცხრილის წაშლა',
	rows: 'რიგი',
	columns: 'სვეტი',
	add_head: 'სათაურის დამატება',
	delete_head: 'სათაურის წაშლა',
	title: 'სათაური',
	image_position: 'მდებარეობა',
	none: 'არსად',
	left: 'მარცხნივ',
	right: 'მარჯვნივ',
	image_web_link: 'სურათის ვებ-მისამართი',
	text: 'ტექსტი',
	mailto: 'ელ. მისამართი',
	web: 'მისამართი',
	video_html_code: 'ვიდეოს HTML Embed კოდი',
	file: 'ფაილის ჩასმა',
	upload: 'ატვირთვა',
	download: 'ჩამოტვირთვა',
	choose: 'არჩევა',
	or_choose: 'ან აირჩიეთ',
	drop_file_here: 'ჩააგდეთ ფაილი აქ',
	align_left:	'მარცხენა მხრიდან',
	align_center: 'ცენტრში',
	align_right: 'მარჯვენა მხრიდან',
	align_justify: 'ორივე მხრიდან',
	horizontalrule: 'ჰორიზონტალური ხაზის ჩასმა',
	deleted: 'ხაზგადასმული',
	anchor: 'ბმული',
	link_new_tab: 'ახალ ფანჯარაში გასხნა',
	underline: 'ხაზგასმული',
	alignment: 'ტექსტის გასწორება',
	filename: 'სახელი (არასავალდებულო)',
	edit: 'რედაქტირება',
	center: 'Center'
};
})( jQuery );
