(function ($) {
$.Redactor.opts.langs['pt_pt'] = {
	html: 'HTML',
	video: 'Inserir Video...',
	image: 'Inserir Imagem...',
	table: 'Tabela',
	link: 'Hiperligação',
	link_insert: 'Inserir Hiperligação ...',
	link_edit: 'Edit link',
	unlink: 'Remover Hiperligação',
	formatting: 'Formatação',
	paragraph: 'Parágrafo',
	quote: 'Citar',
	code: 'Código',
	header1: 'Cabeçalho 1',
	header2: 'Cabeçalho 2',
	header3: 'Cabeçalho 3',
	header4: 'Cabeçalho 4',
	header5: 'Cabeçalho 5',
	bold:  'Negrito',
	italic: 'Itálico',
	fontcolor: 'Cor da Fonte',
	backcolor: 'Cor de Fundo',
	unorderedlist: 'Lista Não Ordenada',
	orderedlist: 'Lista Ordenada',
	outdent: 'Remover Identação',
	indent: 'Identar',
	cancel: 'Cancelar',
	insert: 'Inserir',
	save: 'Guardar',
	_delete: 'Eliminar',
	insert_table: 'Inserir Tabela...',
	insert_row_above: 'Adicionar Linha Acima',
	insert_row_below: 'Adicionar Linha Abaixo',
	insert_column_left: 'Adicionar Coluna à Esquerda',
	insert_column_right: 'Adicionar Coluna à Direita',
	delete_column: 'Eliminar Coluna',
	delete_row: 'Eliminar Linha',
	delete_table: 'Eliminar Tabela',
	rows: 'Linhas',
	columns: 'Colunas',
	add_head: 'Adicionar Cabeçalho',
	delete_head: 'Eliminar Cabeçalho',
	title: 'Título',
	image_position: 'Posição',
	none: 'Nenhum',
	left: 'Esquerda',
	right: 'Direita',
	image_web_link: 'Url de Imagem',
	text: 'Texto',
	mailto: 'Email',
	web: 'URL',
	video_html_code: 'Código de Incorporação de Vídeo',
	file: 'Inserir Ficheiro...',
	upload: 'Upload',
	download: 'Download',
	choose: 'Escolha',
	or_choose: 'Ou escolha',
	drop_file_here: 'Largue o ficheiro aqui',
	align_left:	'Alinhar à esquerda',
	align_center: 'Centrar',
	align_right: 'Alinhar à direita',
	align_justify: 'Justificar',
	horizontalrule: 'Inserir Linha Horizontal',
	deleted: 'Eliminado',
	anchor: 'Âncora',
	link_new_tab: 'Abrir hiperligação em novo separador',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
