(function ($) {
$.Redactor.opts.langs['th'] = {
	html: 'HTML',
	video: 'ใส่วีดีโอ...',
	image: 'แนบรูป...',
	table: 'ตาราง',
	link: 'ลิงค์',
	link_insert: 'ใส่ลิงค์ ...',
	link_edit: 'Edit link',
	unlink: 'ลบลิงค์',
	formatting: 'รูปแบบ',
	paragraph: 'ย่อหน้า',
	quote: 'ข้อความ',
	code: 'โค้ด',
	header1: 'หัวข้อ 1',
	header2: 'หัวข้อ 2',
	header3: 'หัวข้อ 3',
	header4: 'หัวข้อ 4',
	header5: 'หัวข้อ 5',
	bold:  'ตัวหน้า',
	italic: 'ตัวเอียง',
	fontcolor: 'สีตัวอักษร',
	backcolor: 'สีพื้นหลัง',
	unorderedlist: 'รายการแบบไม่มีลำดับ',
	orderedlist: 'รายการแบบมีลำดับ',
	outdent: 'เลื่อนออก',
	indent: 'เลื่อนเข้า',
	cancel: 'ยกเลิก',
	insert: 'แนบ',
	save: 'บันทึก',
	_delete: 'ลบ',
	insert_table: 'ใส่ตาราง...',
	insert_row_above: 'แทรกแถวใหม่ด้านบน',
	insert_row_below: 'แทรกแถวใหม่ด้านล่าง',
	insert_column_left: 'แทรกคอลัมน์ทางซ้าย',
	insert_column_right: 'แทรกคอลัมน์ทางขวา',
	delete_column: 'ลบคอลัมน์',
	delete_row: 'ลบแถว',
	delete_table: 'ลบตาราง',
	rows: 'แถว',
	columns: 'คอลัมน์',
	add_head: 'ใส่หัวข้อ',
	delete_head: 'ลบหัวข้อ',
	title: 'หัวเรื่อง',
	image_position: 'ตำแหน่งรูป',
	none: 'ปรกติ',
	left: 'ซ้าย',
	right: 'ขวา',
	image_web_link: 'ลิงค์รูปภาพ',
	text: 'ตัวอักษร',
	mailto: 'อีเมล',
	web: 'เว็บไซต์',
	video_html_code: 'โค้ดวีดีโอ',
	file: 'แนบไฟล์...',
	upload: 'อัพโหลด',
	download: 'ดาวน์โหลด',
	choose: 'เลือก',
	or_choose: 'หรือเลือกไฟล์',
	drop_file_here: 'ลากไฟล์มาวางที่นี่',
	align_left:	'จัดตัวอักษรชิดซ้าย',
	align_center: 'จัดตัวอักษรกึ่งกลาง',
	align_right: 'จัดตัวอักษรชิดขวา',
	align_justify: 'จัดตัวอักษรแบบพอดีกรอบ',
	horizontalrule: 'ใส่เส้นแบ่งหน้า',
	deleted: 'ขีดออก',
	anchor: 'เชื่อมโยง',
	link_new_tab: 'เปิดลิงค์ในแทปใหม่',
	underline: 'เส้นใต้',
	alignment: 'การจัดวาง',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
