(function ($) {
$.Redactor.opts.langs['sr-cir'] = {
	html: 'ХТМЛ',
	video: 'Убаци видео',
	image: 'Убаци фотографију',
	table: 'Табела',
	link: 'Веза',
	link_insert: 'Убаци везу ...',
	link_edit: 'Edit link',
	unlink: 'Уклони везу',
	formatting: 'Стилови',
	paragraph: 'Параграф',
	quote: 'Цитат',
	code: 'Изворни код',
	header1: 'Заглавље 1',
	header2: 'Заглавље 2',
	header3: 'Заглавље 3',
	header4: 'Заглавље 4',
	header5: 'Заглавље 5',
	bold: 'Подебљај',
	italic: 'Накоси',
	fontcolor: 'Боја слова',
	backcolor: 'Боја позадине',
	unorderedlist: 'Несортирана листа',
	orderedlist: 'Сортирана листа',
	outdent: 'Извуци',
	indent: 'Увуци',
	redo: 'Корак напред',
	undo: 'Корак назад',
	cut: 'Изрежи',
	cancel: 'Одустани',
	insert: 'Убаци',
	save: 'Сачувај',
	_delete: 'Избриши',
	insert_table: 'Убаци табелу',
	insert_row_above: 'Додај ред изнад',
	insert_row_below: 'Додај ред испод',
	insert_column_left: 'Додај колону лево',
	insert_column_right: 'Додај колону десно',
	delete_column: 'Избриши колону',
	delete_row: 'Избриши ред',
	delete_table: 'Избриши табелу',
	rows: 'Ред',
	columns: 'Колона',
	add_head: 'Додај заглавље',
	delete_head: 'Уклони заглавље',
	title: 'Наслов',
	image_position: 'Позиција',
	none: 'Без',
	left: 'Лево',
	right: 'Десно',
	image_web_link: 'Веб адреса фотографије',
	text: 'Текст',
	mailto: 'Емаил',
	web: 'Веб адреса',
	video_html_code: 'Видео код',
	file: 'Датотека',
	upload: 'Пошаљи',
	download: 'Преузми',
	choose: 'Одабери',
	or_choose: 'Или одабери',
	drop_file_here: 'Превуци датотеку овде',
	align_left:	'Поравнај лево',
	align_center: 'Центрирај',
	align_right: 'Поравнај десно',
	align_justify: 'Од руба до руба',
	horizontalrule: 'Убаци хоризонталну линију',
	fullscreen: 'Прикажи преко читавог екрана',
	deleted: 'Избрисано',
	anchor: 'Сидро',
	link_new_tab: 'Open link in new tab',
	underline: 'Underline',
	alignment: 'Alignment',
	filename: 'Name (optional)',
	edit: 'Edit',
	center: 'Center'
};
})( jQuery );
